diff --git a/GMW-RT/bin/GMW-RT.dll b/GMW-RT/bin/GMW-RT.dll
index f18f96e1..878654ed 100644
Binary files a/GMW-RT/bin/GMW-RT.dll and b/GMW-RT/bin/GMW-RT.dll differ
diff --git a/GMW-RT/bin/GMW_data.dll b/GMW-RT/bin/GMW_data.dll
index bd2f4a98..0af44799 100644
Binary files a/GMW-RT/bin/GMW_data.dll and b/GMW-RT/bin/GMW_data.dll differ
diff --git a/GMW-RT/bin/SteamWare.dll b/GMW-RT/bin/SteamWare.dll
index c41f511a..b40df9dc 100644
Binary files a/GMW-RT/bin/SteamWare.dll and b/GMW-RT/bin/SteamWare.dll differ
diff --git a/GMW-UT/bin/GMW-UT.dll b/GMW-UT/bin/GMW-UT.dll
index ab1a29a6..dcf50ffe 100644
Binary files a/GMW-UT/bin/GMW-UT.dll and b/GMW-UT/bin/GMW-UT.dll differ
diff --git a/GMW-UT/bin/GMW_data.dll b/GMW-UT/bin/GMW_data.dll
index bd2f4a98..0af44799 100644
Binary files a/GMW-UT/bin/GMW_data.dll and b/GMW-UT/bin/GMW_data.dll differ
diff --git a/GMW-UT/bin/SteamWare.dll b/GMW-UT/bin/SteamWare.dll
index c41f511a..b40df9dc 100644
Binary files a/GMW-UT/bin/SteamWare.dll and b/GMW-UT/bin/SteamWare.dll differ
diff --git a/GMW/GMW.csproj b/GMW/GMW.csproj
index 287f0561..6ad74f92 100644
--- a/GMW/GMW.csproj
+++ b/GMW/GMW.csproj
@@ -451,7 +451,6 @@
compilerconfig.json
-
diff --git a/GMW/GMW.csproj.user b/GMW/GMW.csproj.user
index b9513f4d..3b0d8d98 100644
--- a/GMW/GMW.csproj.user
+++ b/GMW/GMW.csproj.user
@@ -2,7 +2,7 @@
ShowAllFiles
- TK_test
+ IIS02_TK
diff --git a/GMW/Properties/PublishProfiles/TK_prod.pubxml b/GMW/Properties/PublishProfiles/TK_prod.pubxml
index d4889fe6..7ca66b8d 100644
--- a/GMW/Properties/PublishProfiles/TK_prod.pubxml
+++ b/GMW/Properties/PublishProfiles/TK_prod.pubxml
@@ -18,11 +18,11 @@ by editing this MSBuild file. In order to learn more about this please visit htt
-
+
diff --git a/GMW/Properties/PublishProfiles/Test218.pubxml b/GMW/Properties/PublishProfiles/Test218.pubxml
deleted file mode 100644
index 836e9b31..00000000
--- a/GMW/Properties/PublishProfiles/Test218.pubxml
+++ /dev/null
@@ -1,23 +0,0 @@
-
-
-
-
- MSDeploy
- Release
- Any CPU
-
- True
- False
- https://10.74.82.218:8172/MsDeploy.axd
- Default Web Site/GMW
-
- True
- WMSVC
- True
- Administrator
- <_SavePWD>True
-
-
\ No newline at end of file
diff --git a/GMW/Properties/PublishProfiles/Test218.pubxml.user b/GMW/Properties/PublishProfiles/Test218.pubxml.user
deleted file mode 100644
index aa317686..00000000
--- a/GMW/Properties/PublishProfiles/Test218.pubxml.user
+++ /dev/null
@@ -1,11 +0,0 @@
-
-
-
-
- 2014-10-23T19:00:49.9701048+02:00
- AQAAANCMnd8BFdERjHoAwE/Cl+sBAAAADfdPkbM5mUeaV6YvQx8NEwAAAAACAAAAAAADZgAAwAAAABAAAABretqmeAwoN8dwwUym0l6uAAAAAASAAACgAAAAEAAAANS9Yunkzc8Nyn9LraBErMgQAAAArKgvGhTAwNnTbdGD8tmWohQAAAC/UZP/r9BIjbarE1TjmEMK+wszYw==
-
-
\ No newline at end of file
diff --git a/GMW/Web.config b/GMW/Web.config
index d870a24c..46055040 100644
--- a/GMW/Web.config
+++ b/GMW/Web.config
@@ -72,6 +72,12 @@
+
+
+
+
+
+
@@ -247,12 +253,6 @@
-
-
-
-
-
-
diff --git a/GMW/bin/GMW.dll b/GMW/bin/GMW.dll
index cc601eb1..b9e19397 100644
Binary files a/GMW/bin/GMW.dll and b/GMW/bin/GMW.dll differ
diff --git a/GMW/bin/GMW.dll.config b/GMW/bin/GMW.dll.config
index 5641d2e5..8dcebe75 100644
--- a/GMW/bin/GMW.dll.config
+++ b/GMW/bin/GMW.dll.config
@@ -72,6 +72,12 @@
+
+
+
+
+
+
@@ -247,12 +253,6 @@
-
-
-
-
-
-
diff --git a/GMW/WebUserControls/mod_anime.ascx.cs b/GMW/WebUserControls/mod_anime.ascx.cs
index c6e40781..9ae0bda7 100644
--- a/GMW/WebUserControls/mod_anime.ascx.cs
+++ b/GMW/WebUserControls/mod_anime.ascx.cs
@@ -73,7 +73,7 @@ namespace GMW.WebUserControls
///
private void checkNumKeyIn()
{
- if(memLayer.ML.isInSessionObject("numKeyIn"))
+ if (memLayer.ML.isInSessionObject("numKeyIn"))
{
barcodeIn = memLayer.ML.StringSessionObj("numKeyIn");
// svuoto valore in sessione...
@@ -488,55 +488,69 @@ namespace GMW.WebUserControls
// !!!FARE!!!
// controllo che abbia CodSogg auth...
// OC Soggetto creatore UDC --> mettere "OC" in web.config
// verifico postazione x procedere...
if (Postazione.printer != "n.d.")
{
- string newUdcChild = "";
- string noteTrim = txtNote.Text.Trim();
- // effettuo controlli che cod_soggetto e cod particolare siano disponibili...
- string codSogg = "";
- string particolare = "";
- try
+ // verifico auth utente...
+ if (OpAuth.isAuth)
{
- codSogg = MagClass.magazzino.CodSoggCurrUser;
- particolare = currParticolare;
- }
- catch
- {
- }
- if (codSogg != "" && particolare != "")
- {
- // genero cartellino liquidi
- DateTime adesso = DateTime.Now;
+ string newUdcChild = "";
+ string noteTrim = txtNote.Text.Trim();
+ // effettuo controlli che cod_soggetto e cod particolare siano disponibili...
+ string codSogg = "";
+ string particolare = "";
try
{
- // creo nuovo UDC del trattamento liquidi
- newUdcChild = MagClass.magazzino.creaUdc(flusso, "", particolare, "", "", "", "", "", 0, memLayer.ML.confReadString("CodImballoAnime"), "U", codSogg, qta, 0, 0, adesso, 0, statoUDC, memLayer.ML.confReadInt("IdxPosizioneAnime"), "IdxPosizioneAnime", "UDC_ANIMA", noteTrim, "", adesso.Year, Request.UserHostName);
- // registro creazione nuovo UDC
- MagClass.magazzino.taSAO.insertQuery(adesso, codSogg, Postazione.name, Postazione.IP, newUdcChild, particolare, "creaUDC", string.Format("Creato nuovo UDC Anime - qta:{0} {1}", qta, noteTrim));
+ codSogg = MagClass.magazzino.CodSoggCurrUser;
+ particolare = currParticolare;
}
- catch (Exception exc)
+ catch
{
- httpLog(string.Format("Errore creazione UDC anime: {0}", exc), tipoLog.EXCEPTION);
}
- // se ho cart stampo!
- if (newUdcChild != "")
+ if (codSogg != "" && particolare != "")
{
- // ora stampo il nuovo cartellino!!!
- MagClass.magazzino.stampaUdc(newUdcChild, Postazione.printer, tipoCartellino.cartAnime, Request.UserHostName);
- // incremento timing...
- adesso = DateTime.Now;
- adesso = adesso.AddSeconds(1);
- // registro stampa nuovo UDC
- MagClass.magazzino.taSAO.insertQuery(adesso, codSogg, Postazione.name, Postazione.IP, newUdcChild, particolare, "stampaUDC", "Stampato UDC Anime");
+ // genero cartellino liquidi
+ DateTime adesso = DateTime.Now;
+ try
+ {
+ // creo nuovo UDC del trattamento liquidi
+ newUdcChild = MagClass.magazzino.creaUdc(flusso, "", particolare, "", "", "", "", "", 0, memLayer.ML.confReadString("CodImballoAnime"), "U", codSogg, qta, 0, 0, adesso, 0, statoUDC, memLayer.ML.confReadInt("IdxPosizioneAnime"), "IdxPosizioneAnime", "UDC_ANIMA", noteTrim, "", adesso.Year, Request.UserHostName);
+ // salvo attributo dell'OpAuth...
+ MagClass.magazzino.taAtt2UDC.Insert(newUdcChild, memLayer.ML.CRS("attrOpAuth"), OpAuth.currAuth.CodSoggetto, DateTime.Now, codSogg);
+ // consumo una auth...
+ OpAuth.currAuth.remAuth--;
+ // registro creazione nuovo UDC
+ MagClass.magazzino.taSAO.insertQuery(adesso, codSogg, Postazione.name, Postazione.IP, newUdcChild, particolare, "creaUDC", string.Format("Creato nuovo UDC Anime - qta:{0} {1}", qta, noteTrim));
+ }
+ catch (Exception exc)
+ {
+ httpLog(string.Format("Errore creazione UDC anime: {0}", exc), tipoLog.EXCEPTION);
+ }
+ // se ho cart stampo!
+ if (newUdcChild != "")
+ {
+ // ora stampo il nuovo cartellino!!!
+ MagClass.magazzino.stampaUdc(newUdcChild, Postazione.printer, tipoCartellino.cartAnime, Request.UserHostName);
+ // incremento timing...
+ adesso = DateTime.Now;
+ adesso = adesso.AddSeconds(1);
+ // registro stampa nuovo UDC
+ MagClass.magazzino.taSAO.insertQuery(adesso, codSogg, Postazione.name, Postazione.IP, newUdcChild, particolare, "stampaUDC", "Stampato UDC Anime");
+ }
+ }
+ else
+ {
+ httpLog(string.Format("Errore persi utente/particolare, ricarico!"), tipoLog.ERROR);
+ Response.Redirect("~/login.aspx");
}
}
else
{
- httpLog(string.Format("Errore persi utente/particolare, ricarico!"), tipoLog.ERROR);
- Response.Redirect("~/login.aspx");
+ Postazione.messaggiText = traduci("noOpAuth");
+ Postazione.CssClass = "stileComandoKo";
+ httpLog(string.Format("Errore manca OpAuth x UDC anime"), tipoLog.ERROR);
}
}
else
@@ -488,55 +488,69 @@ namespace GMW.WebUserControls
// !!!FARE!!!
// controllo che abbia CodSogg auth...
- // OC Soggetto creatore UDC --> mettere "OC" in web.config
+ // OC Soggetto creatore UDC --> "OC" in web.config "attrOpAuth"
// verifico postazione x procedere...
if (Postazione.printer != "n.d.")
diff --git a/GMW/bin/GMW_data.dll b/GMW/bin/GMW_data.dll
index bd2f4a98..0af44799 100644
Binary files a/GMW/bin/GMW_data.dll and b/GMW/bin/GMW_data.dll differ
diff --git a/GMW/bin/SteamWare.dll b/GMW/bin/SteamWare.dll
index c41f511a..b40df9dc 100644
Binary files a/GMW/bin/SteamWare.dll and b/GMW/bin/SteamWare.dll differ
diff --git a/GMW/bin/VersGen.dll b/GMW/bin/VersGen.dll
index 9ec10791..61103eee 100644
Binary files a/GMW/bin/VersGen.dll and b/GMW/bin/VersGen.dll differ
diff --git a/GMW_data/bin/TK_prod/GMW_data.dll b/GMW_data/bin/TK_prod/GMW_data.dll
index e307db45..4b068f38 100644
Binary files a/GMW_data/bin/TK_prod/GMW_data.dll and b/GMW_data/bin/TK_prod/GMW_data.dll differ
diff --git a/GMW_data/bin/TK_prod/SteamWare.dll b/GMW_data/bin/TK_prod/SteamWare.dll
index 162ee44e..b40df9dc 100644
Binary files a/GMW_data/bin/TK_prod/SteamWare.dll and b/GMW_data/bin/TK_prod/SteamWare.dll differ
diff --git a/ReleaseClienti/TK_prod/GMW.zip b/ReleaseClienti/TK_prod/GMW.zip
index eccbcba9..ee49f6b6 100644
Binary files a/ReleaseClienti/TK_prod/GMW.zip and b/ReleaseClienti/TK_prod/GMW.zip differ
diff --git a/ReleaseClienti/TK_test/GMW.zip b/ReleaseClienti/TK_test/GMW.zip
index f4610855..3131694c 100644
Binary files a/ReleaseClienti/TK_test/GMW.zip and b/ReleaseClienti/TK_test/GMW.zip differ